@@ -639,6 +639,32 @@ def convert(name):
         # Weapon
         'peacekeeper': '和平捍卫者',
         'spitfire': '喷火轻机枪',
+        'longbow': '长弓',
+        'volt': '电能冲锋枪',
+        'havoc': '哈沃克步枪',
+        'flatline': '平行步枪',
+        'hemlok': '赫姆洛克突击步枪',
+        'r-301': 'R-301 卡宾枪',
+        'alternator': '转换者冲锋枪',
+        'prowler': '猎兽冲锋枪',
+        'r-99': 'R-99 冲锋枪',
+        'car': 'CAR',
+        'devotion': '专注轻机枪',
+        'l-star': 'L-STAR 能量机枪',
+        'rampage': '暴走',
+        'g7-scout': 'G7 侦察枪',
+        'triple-take': '三重式狙击枪',
+        'repeater': '30-30',
+        'bow': '波塞克',
+        'charge-rifle': '充能步枪',
+        'kraber': '克雷贝尔狙击枪',
+        'sentinel': '哨兵狙击步枪',
+        'eva': 'EVA-8',
+        'mastiff': '敖犬霰弹枪',
+        'mozambique': '莫桑比克',
+        're-45': 'RE-45 自动手枪',
+        'p2020': 'P2020 手枪',
+        'wingman': '辅助手枪',
         # API
         'offline': '离线',
         'online': '在线',
